summaryrefslogtreecommitdiff
path: root/NxWidgets/libnxwidgets/src/ccallback.cxx
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-05-19 01:01:00 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-05-19 01:01:00 +0000
commita591b9ca86b86684f2804cedf5d0c17a3614e913 (patch)
treeb60235b0a038088298aa0f5497411fcb453c424d /NxWidgets/libnxwidgets/src/ccallback.cxx
parent6cf694d2da5a661373a58c70e3d8e07cc8223eed (diff)
downloadnuttx-a591b9ca86b86684f2804cedf5d0c17a3614e913.tar.gz
nuttx-a591b9ca86b86684f2804cedf5d0c17a3614e913.tar.bz2
nuttx-a591b9ca86b86684f2804cedf5d0c17a3614e913.zip
NxWM: Add a missing part of the message blocking logic
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@4748 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'NxWidgets/libnxwidgets/src/ccallback.cxx')
-rw-r--r--NxWidgets/libnxwidgets/src/ccallback.cxx13
1 files changed, 7 insertions, 6 deletions
diff --git a/NxWidgets/libnxwidgets/src/ccallback.cxx b/NxWidgets/libnxwidgets/src/ccallback.cxx
index 32c5b7d64..b2256c6bb 100644
--- a/NxWidgets/libnxwidgets/src/ccallback.cxx
+++ b/NxWidgets/libnxwidgets/src/ccallback.cxx
@@ -211,22 +211,23 @@ void CCallback::newKeyboardEvent(NXHANDLE hwnd, uint8_t nCh,
* callbacks can lead to bad behavior when the callback is executed.
*
* @param hwnd. Window handle of the blocked window
* @param arg. User provided argument (see nx_openwindow, nx_requestbkgd,
* nxtk_openwindow, or nxtk_opentoolbar)
+ * @param arg2 - User provided argument (see nx_block or nxtk_block)
*/
#ifdef CONFIG_NX_MULTIUSER
-void CCallback::windowBlocked(NXWINDOW hwnd, FAR void *arg)
+void CCallback::windowBlocked(NXWINDOW hwnd, FAR void *arg1, FAR void *arg2)
{
- gvdbg("hwnd=%p arg=%p\n", hwnd, arg);
+ gvdbg("hwnd=%p arg1=%p arg2=%p\n", hwnd, arg1, arg2);
- // The argument must be the CWidgetControl instance
+ // The first argument must be the CWidgetControl instance
- CWidgetControl *This = (CWidgetControl *)arg;
+ CWidgetControl *This = (CWidgetControl *)arg1;
// Just forward the callback to the CWidgetControl::windowBlocked method
- This->windowBlocked();
+ This->windowBlocked(arg2);
}
#endif
@@ -211,22 +211,23 @@ void CCallback::newKeyboardEvent(NXHANDLE hwnd, uint8_t nCh,
*
* @param hwnd. Window handle of the blocked window
- * @param arg. User provided argument (see nx_openwindow, nx_requestbkgd,
+ * @param arg1. User provided argument (see nx_openwindow, nx_requestbkgd,
* nxtk_openwindow, or nxtk_opentoolbar)